@@ -142,7 +142,7 @@ def select_port():
 def write_port_to_file(port):
     with open('/application/.runtime/status.json', 'r') as json_file:
         data = json.load(json_file)
-        data["workflow-engine"]["port"] = port
+        data["python-executor"]["port"] = port
     with open('/application/.runtime/status.json', 'w') as output_file:
         json.dump(data, output_file)
 
